Beetle is a python 3 package with tools necessary for transferring data from a MongoDB database to a SQL Server Database. A well defined configuration file allows the user to define the exact way data from MongoDB should be transferred to SQL Server, making Beetle a powerful tool for ETL solutions where transferring data from databases is necessary. The package comes equipped with a standalone executable as well as a modular execution setup enabling easy API or custom script integration.

For More information visit our Gitlab repository: 

https://gitlab.com/Open-Interject/Beetle-ETL